Documentation
¶
Overview ¶
Package wlan provides an i3bar module for wireless information. NOTE: This module REQUIRES the external command "iwgetid", because getting the SSID is a privileged operation.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Info ¶
type Info struct {
Name string
State netlink.OperState
IPs []net.IP
SSID string
AccessPointMAC string
Channel int
Frequency unit.Frequency
}
Info represents the wireless card status.
func (Info) Connected ¶
Connected returns true if connected to a wireless network.
func (Info) Connecting ¶
Connecting returns true if a connection is in progress.
type Module ¶
type Module struct {
// contains filtered or unexported fields
}
Module represents a wlan bar module.
func Any ¶
func Any() *Module
Any constructs an instance of the wlan module that uses any available wireless interface, choosing the 'best' state from all available.
func Named ¶
Named constructs an instance of the wlan module for the specified interface.
func (*Module) Output ¶
Output configures a module to display the output of a user-defined function.
Source Files
¶
- wlan.go